==> texlive-bin_2017.20170613.44572.orig.tar.xz: texlive-bin-2017.20170613.44572/texk/dvisvgm/dvisvgm-src/tests/PageSizeTest.cpp <==
/*************************************************************************
** PageSizeTest.cpp                                                     **
**                                                                      **
** This file is part of dvisvgm -- a fast DVI to SVG converter          **
** Copyright (C) 2005-2017 Martin Gieseking <martin.gieseking@uos.de>   **
**                                                                      **
** This program is free software; you can redistribute it and/or        **
** modify it under the terms of the GNU General Public License as       **
** published by the Free Software Foundation; either version 3 of       **
** the License, or (at your option) any later version.                  **
**                                                                      **
** This program is distributed in the hope that it will be useful, but  **
** WITHOUT ANY WARRANTY; without even the implied warranty of           **
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the         **
** GNU General Public License for more details.                         **
**                                                                      **
** You should have received a copy of the GNU General Public License    **
** along with this program; if not, see <http://www.gnu.org/licenses/>. **
*************************************************************************/

#include <gtest/gtest.h>
#include <limits>
#include "PageSize.hpp"


class PageSizeTest : public ::testing::Test
{
	protected:
		struct PageData 
		{
			const char *id;
			double width, height;
		};

		static const PageData pageData[];
		
		PageSize ps;
};


const PageSizeTest::PageData PageSizeTest::pageData[] = {
	{"A4", 210, 297},
	{"a4", 210, 297}, 
	{"a4-p", 210, 297}, 
	{"a4-portrait", 210, 297}, 
	{"a4-l", 297, 210}, 
	{"a4-landscape", 297, 210}, 
	{"a5", 148, 210}, 
	{"c10", 28, 40},
	{"letter", 216, 279},
	{0, 0, 0}
};


TEST_F(PageSizeTest, resize) {
	EXPECT_FALSE(ps.valid());
	
	for (const PageData *p = pageData; p && p->id; p++) {
		ps.resize(p->id);
		EXPECT_DOUBLE_EQ(ps.widthInMM(), p->width);
		EXPECT_DOUBLE_EQ(ps.heightInMM(), p->height);
	}
}


TEST_F(PageSizeTest, exceptions) {
	EXPECT_THROW(ps.resize("a"), PageSizeException);
	EXPECT_THROW(ps.resize("e4"), PageSizeException);
	EXPECT_THROW(ps.resize("a4-unknown"), PageSizeException);
}

==> texlive-bin_2018.20181218.49446.orig.tar.xz: texlive-bin-2018.20181218.49446/texk/dvisvgm/dvisvgm-src/tests/PageSizeTest.cpp <==
/*************************************************************************
** PageSizeTest.cpp                                                     **
**                                                                      **
** This file is part of dvisvgm -- a fast DVI to SVG converter          **
** Copyright (C) 2005-2018 Martin Gieseking <martin.gieseking@uos.de>   **
**                                                                      **
** This program is free software; you can redistribute it and/or        **
** modify it under the terms of the GNU General Public License as       **
** published by the Free Software Foundation; either version 3 of       **
** the License, or (at your option) any later version.                  **
**                                                                      **
** This program is distributed in the hope that it will be useful, but  **
** WITHOUT ANY WARRANTY; without even the implied warranty of           **
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the         **
** GNU General Public License for more details.                         **
**                                                                      **
** You should have received a copy of the GNU General Public License    **
** along with this program; if not, see <http://www.gnu.org/licenses/>. **
*************************************************************************/

#include <gtest/gtest.h>
#include <vector>
#include "PageSize.hpp"

using namespace std;


struct PageData {
	const char *name;
	double width, height;  // in mm
};


const vector<PageData> pageData = {
	{"A4", 210, 297},
	{"a4", 210, 297},
	{"a4-p", 210, 297},
	{"a4-portrait", 210, 297},
	{"a4-l", 297, 210},
	{"a4-landscape", 297, 210},
	{"a5", 148, 210},
	{"b2", 500, 707},
	{"c10", 28, 40},
	{"D3", 272, 385},
	{"letter", 216, 279}
};


TEST(PageSizeTest, resize) {
	PageSize pageSize;
	EXPECT_FALSE(pageSize.valid());
	for (const PageData &data : pageData) {
		pageSize.resize(data.name);
		EXPECT_DOUBLE_EQ(pageSize.width().mm(), data.width) << data.name;
		EXPECT_DOUBLE_EQ(pageSize.height().mm(), data.height) << data.name;
	}
}


TEST(PageSizeTest, exceptions) {
	PageSize pageSize;
	EXPECT_THROW(pageSize.resize("a"), PageSizeException);
	EXPECT_THROW(pageSize.resize("e4"), PageSizeException);
	EXPECT_THROW(pageSize.resize("a4-unknown"), PageSizeException);
}
